Disclaimer — Football Packing 0.1 documentation

# Disclaimer

The concept of packing belongs to Impect and I do not take credit for the metric.

This is an attempt to create an open source variation of it, with few modifications on how the metrics are calculated. The logic behind the metric calculations are explained here in this section.

For any questions/feedback, reach out to me on twitter @SamiraK93.

If you’d like to file any issues/updates, submit a PR on GitHub.